Rnanoflann-package: Extremely Fast Nearest Neighbor Search

Rnanoflann-packageR Documentation

Extremely Fast Nearest Neighbor Search

Description

Finds the k nearest neighbours for every point in a given dataset using Jose Luis' 'nanoflann' library. There is support for exact searches, fixed radius searches with 'kd' trees and two distances, the 'Euclidean' and 'Manhattan'. For more information see <https://github.com/jlblancoc/nanoflann>. Also, the 'nanoflann' library is exported and ready to be used via the linking to mechanism.

Details

Package: \packageNameRnanoflann
Type: \packageTypeRnanoflann
Version: \packageVersionRnanoflann
Date: \packageDateRnanoflann
License: \packageLicenseRnanoflann

Author(s)

Authors: \packageAuthorsRnanoflann

Maintainer: Manos Papadakis <papadakm95@gmail.com>


Rnanoflann documentation built on Nov. 2, 2023, 5:21 p.m.