| Rnanoflann-package | R Documentation |
Finds the k nearest neighbours for every point in a given dataset using Jose Luis' 'nanoflann' library. There is support for exact searches, fixed radius searches with 'kd' trees and two distances, the 'Euclidean' and 'Manhattan'. For more information see <https://github.com/jlblancoc/nanoflann>. Also, the 'nanoflann' library is exported and ready to be used via the linking to mechanism.
| Package: | \packageNameRnanoflann |
| Type: | \packageTypeRnanoflann |
| Version: | \packageVersionRnanoflann |
| Date: | \packageDateRnanoflann |
| License: | \packageLicenseRnanoflann |
Authors: \packageAuthorsRnanoflann
Maintainer: Manos Papadakis <papadakm95@gmail.com>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.